marktools.detach_noncontext_marks_attached_to_component
=======================================================

.. autofunction:: abjad.tools.marktools.detach_noncontext_marks_attached_to_component.detach_noncontext_marks_attached_to_component
